pub struct EpistemicSolverAssumptionBinding {
pub literal_index: usize,
pub reduction_index: usize,
pub predicate: String,
pub arity: usize,
pub terms: Vec<EirTerm>,
pub op: EirEpistemicOp,
pub negated: bool,
}Expand description
Binding from an epistemic literal to a solver assumption obligation.
Fields
literal_index: usizeIndex of the epistemic literal in EpistemicGpuPlan::epistemic_literals.
reduction_index: usizeIndex of the reduced rule in EpistemicGpuPlan::reductions.
predicate: StringPredicate whose epistemic truth becomes a solver assumption.
arity: usizePredicate arity for the solver assumption.
terms: Vec<EirTerm>Source atom terms that define the solver assumption key.
op: EirEpistemicOpEpistemic operator represented by the assumption.
negated: boolWhether the epistemic literal is explicitly negated.